@@ -36,54 +36,35 @@ const VoiceResponse_1 = __importDefault(require("./twiml/VoiceResponse"));
 const MessagingResponse_1 = __importDefault(require("./twiml/MessagingResponse"));
 const FaxResponse_1 = __importDefault(require("./twiml/FaxResponse"));
 // Shorthand to automatically create a RestClient
-var initializer = function (accountSid, authToken, opts) {
-    return new Twilio_1.default(accountSid, authToken, opts);
-};
-// Main functional components of the Twilio module
-initializer.Twilio = Twilio_1.default;
-initializer.jwt = {};
-initializer.twiml = {};
-initializer.RequestClient = RequestClient_1.default;
-Object.defineProperty(initializer.jwt, "AccessToken", {
-    get: function () {
-        return AccessToken_1.default;
-    },
-});
-Object.defineProperty(initializer.jwt, "ClientCapability", {
-    get: function () {
-        return ClientCapability_1.default;
-    },
-});
-Object.defineProperty(initializer.jwt, "taskrouter", {
-    get: function () {
-        return {
-            TaskRouterCapability: TaskRouterCapability_1.default,
-            util: taskRouterUtil,
-        };
-    },
-});
-Object.defineProperty(initializer.twiml, "VoiceResponse", {
-    get: function () {
-        return VoiceResponse_1.default;
-    },
-});
-Object.defineProperty(initializer.twiml, "MessagingResponse", {
-    get: function () {
-        return MessagingResponse_1.default;
-    },
-});
-Object.defineProperty(initializer.twiml, "FaxResponse", {
-    get: function () {
-        return FaxResponse_1.default;
-    },
-});
-// Setup webhook helper functionality
-initializer.validateBody = webhooks.validateBody;
-initializer.validateRequest = webhooks.validateRequest;
-initializer.validateRequestWithBody = webhooks.validateRequestWithBody;
-initializer.validateIncomingRequest = webhooks.validateIncomingRequest;
-initializer.validateExpressRequest = webhooks.validateExpressRequest;
-initializer.getExpectedBodyHash = webhooks.getExpectedBodyHash;
-initializer.getExpectedTwilioSignature = webhooks.getExpectedTwilioSignature;
-initializer.webhook = webhooks.webhook;
-module.exports = initializer;
+function TwilioSDK(accountSid, authToken, opts) {
+    return new TwilioSDK.Twilio(accountSid, authToken, opts);
+}
+(function (TwilioSDK) {
+    TwilioSDK.Twilio = Twilio_1.default;
+    let jwt;
+    (function (jwt) {
+        jwt.AccessToken = AccessToken_1.default;
+        jwt.ClientCapability = ClientCapability_1.default;
+        let taskrouter;
+        (function (taskrouter) {
+            taskrouter.TaskRouterCapability = TaskRouterCapability_1.default;
+            taskrouter.util = taskRouterUtil;
+        })(taskrouter = jwt.taskrouter || (jwt.taskrouter = {}));
+    })(jwt = TwilioSDK.jwt || (TwilioSDK.jwt = {}));
+    let twiml;
+    (function (twiml) {
+        twiml.VoiceResponse = VoiceResponse_1.default;
+        twiml.MessagingResponse = MessagingResponse_1.default;
+        twiml.FaxResponse = FaxResponse_1.default;
+    })(twiml = TwilioSDK.twiml || (TwilioSDK.twiml = {}));
+    TwilioSDK.RequestClient = RequestClient_1.default;
+    TwilioSDK.validateBody = webhooks.validateBody;
+    TwilioSDK.validateRequest = webhooks.validateRequest;
+    TwilioSDK.validateRequestWithBody = webhooks.validateRequestWithBody;
+    TwilioSDK.validateExpressRequest = webhooks.validateExpressRequest;
+    TwilioSDK.validateIncomingRequest = webhooks.validateIncomingRequest;
+    TwilioSDK.getExpectedBodyHash = webhooks.getExpectedBodyHash;
+    TwilioSDK.getExpectedTwilioSignature = webhooks.getExpectedTwilioSignature;
+    TwilioSDK.webhook = webhooks.webhook;
+})(TwilioSDK || (TwilioSDK = {}));
+module.exports = TwilioSDK;
